@@ -82,6 +82,14 @@ class CarouselItemLocalizationAPIUnitTest(TestCase):
         res = req.post(url, data=data, follow=1)
         assert CarouselItemLocalization.objects.filter(pre_heading='posted pre_heading').first()
 
+        # GET LOGS
+        url = reverse('unicms_api:carousel-item-localization-logs',
+                      kwargs={'carousel_id': carousel.pk,
+                              'carousel_item_id': carousel_item.pk,
+                              'pk': carousel_item_localization.pk})
+        res = req.get(url, content_type='application/json',)
+        assert isinstance(res.json(), dict)
+
         # GET, patch, put, delete
         url = reverse('unicms_api:carousel-item-localization',
                       kwargs={'carousel_id': carousel.pk,
