@@ -1,3 +1,4 @@
+from django.contrib.contenttypes.models import ContentType
 from django.http import Http404
 from django.shortcuts import get_object_or_404
 
@@ -14,11 +15,12 @@ from cms.pages.serializers import PageSerializer
 from cms.pages.utils import copy_page_as_draft
 
 from . generics import UniCMSCachedRetrieveUpdateDestroyAPIView, UniCMSListCreateAPIView, check_locks
+from . logs import ObjectLogEntriesList
 from .. exceptions import LoggedPermissionDenied
 from .. serializers import UniCMSFormSerializer
 
 
-class EditorWebpathPageList(UniCMSListCreateAPIView):
+class PageList(UniCMSListCreateAPIView):
     """
     """
     name = "Pages"
@@ -55,7 +57,7 @@ class EditorWebpathPageList(UniCMSListCreateAPIView):
             return super().post(request, *args, **kwargs)
 
 
-class EditorWebpathPageView(UniCMSCachedRetrieveUpdateDestroyAPIView):
+class PageView(UniCMSCachedRetrieveUpdateDestroyAPIView):
     """
     """
     description = ""
@@ -372,3 +374,51 @@ class PageCopyAsDraftView(APIView):
             return Response(result.data)
         raise LoggedPermissionDenied(classname=self.__class__.__name__,
                                      resource=request.method)
+
+
+class PageLogsSchema(AutoSchema):
+    def get_operation_id(self, path, method):# pragma: no cover
+        return 'listPageLogs'
+
+
+class PageLogsView(ObjectLogEntriesList):
+
+    schema = PageLogsSchema()
+
+    def get_queryset(self, **kwargs):
+        """
+        """
+        site_id = self.kwargs.get('site_id')
+        webpath_id = self.kwargs.get('webpath_id')
+        object_id = self.kwargs.get('pk')
+
+        site = get_object_or_404(WebSite, pk=site_id, is_active=True)
+        if not site.is_managed_by(self.request.user):
+            raise LoggedPermissionDenied(classname=self.__class__.__name__,
+                                         resource=site)
+        item = get_object_or_404(Page.objects.select_related('webpath'),
+                                 pk=object_id,
+                                 webpath__pk=webpath_id,
+                                 webpath__site__pk=site_id)
+        content_type_id = ContentType.objects.get_for_model(item).pk
+        return super().get_queryset(object_id, content_type_id)
+
+
+class PageRelatedObjectLogsView(ObjectLogEntriesList):
+
+    def get_data(self):
+        site_id = self.kwargs['site_id']
+        site = get_object_or_404(WebSite, pk=site_id, is_active=True)
+        if not site.is_managed_by(self.request.user):
+            raise LoggedPermissionDenied(classname=self.__class__.__name__,
+                                         resource=site)
+        webpath_id = self.kwargs['webpath_id']
+        page_id = self.kwargs['page_id']
+        self.pk = self.kwargs['pk']
+        self.page = get_object_or_404(Page.objects.select_related('webpath'),
+                                      pk=page_id,
+                                      webpath__pk=webpath_id,
+                                      webpath__site__pk=site_id)
+
+    def get_queryset(self, object_id, content_type_id):
+        return super().get_queryset(object_id, content_type_id)
