@@ -1,4 +1,5 @@
 from django.conf import settings
+from django.contrib.contenttypes.models import ContentType
 from django.http import Http404, HttpResponseRedirect
 from django.shortcuts import get_object_or_404
 from django.urls import reverse
@@ -17,7 +18,8 @@ from rest_framework.response import Response
 from rest_framework.views import APIView
 
 from . generics import UniCMSCachedRetrieveUpdateDestroyAPIView, UniCMSListCreateAPIView, UniCMSListSelectOptionsAPIView
-from .. exceptions import LoggedPermissionDenied
+from . logs import ObjectLogEntriesList
+from .. exceptions import LoggedPermissionDenied, LoggedValidationException
 from .. serializers import UniCMSFormSerializer
 
 
@@ -25,7 +27,7 @@ CMS_CONTEXT_PERMISSIONS = getattr(settings, 'CMS_CONTEXT_PERMISSIONS',
                                   contexts_settings.CMS_CONTEXT_PERMISSIONS)
 
 
-class EditorWebsiteWebpathList(UniCMSListCreateAPIView):
+class WebpathList(UniCMSListCreateAPIView):
     """
     """
     name = "Webpaths"
@@ -59,7 +61,12 @@ class EditorWebsiteWebpathList(UniCMSListCreateAPIView):
             if not publisher_perms or not parent_locks_ok:
                 raise LoggedPermissionDenied(classname=self.__class__.__name__,
                                              resource=request.method)
-            webpath = serializer.save()
+            try:
+                webpath = serializer.save()
+            except Exception as e:
+                raise LoggedValidationException(classname=self.__class__.__name__,
+                                                resource=request.method,
+                                                detail=e)
             # add permission to webpath
             if not publisher_perms['allow_descendant']:
                 EditorialBoardEditors.objects.create(user=request.user,
@@ -72,7 +79,7 @@ class EditorWebsiteWebpathList(UniCMSListCreateAPIView):
             return HttpResponseRedirect(url)
 
 
-class EditorWebsiteWebpathView(UniCMSCachedRetrieveUpdateDestroyAPIView):
+class WebpathView(UniCMSCachedRetrieveUpdateDestroyAPIView):
     """
     Editor user get website webpath permissions
     """
@@ -114,7 +121,12 @@ class EditorWebsiteWebpathView(UniCMSCachedRetrieveUpdateDestroyAPIView):
                 if not has_permission:
                     raise LoggedPermissionDenied(classname=self.__class__.__name__,
                                                  resource=request.method)
-            return super().patch(request, *args, **kwargs)
+            try:
+                return super().patch(request, *args, **kwargs)
+            except Exception as e:
+                raise LoggedValidationException(classname=self.__class__.__name__,
+                                                resource=request.method,
+                                                detail=e)
 
     def put(self, request, *args, **kwargs):
         item = self.get_queryset().first()
@@ -137,7 +149,12 @@ class EditorWebsiteWebpathView(UniCMSCachedRetrieveUpdateDestroyAPIView):
                 if not has_permission:
                     raise LoggedPermissionDenied(classname=self.__class__.__name__,
                                                  resource=request.method)
-            return super().put(request, *args, **kwargs)
+            try:
+                return super().put(request, *args, **kwargs)
+            except Exception as e:
+                raise LoggedValidationException(classname=self.__class__.__name__,
+                                                resource=request.method,
+                                                detail=e)
 
     def delete(self, request, *args, **kwargs):
         item = self.get_queryset().first()
@@ -216,3 +233,28 @@ class WebpathOptionView(generics.RetrieveAPIView):
             raise LoggedPermissionDenied(classname=self.__class__.__name__,
                                          resource=site)
         return WebPath.objects.filter(pk=pk, site=site)
+
+
+class WebpathLogsSchema(AutoSchema):
+    def get_operation_id(self, path, method):# pragma: no cover
+        return 'listWebPathLogs'
+
+
+class WebpathLogsView(ObjectLogEntriesList):
+
+    schema = WebpathLogsSchema()
+
+    def get_queryset(self, **kwargs):
+        """
+        """
+        site_id = self.kwargs['site_id']
+        object_id = self.kwargs['pk']
+        site = get_object_or_404(WebSite, pk=site_id, is_active=True)
+        if not site.is_managed_by(self.request.user):
+            raise LoggedPermissionDenied(classname=self.__class__.__name__,
+                                         resource=site)
+        item = get_object_or_404(WebPath.objects.select_related('site'),
+                                 pk=object_id,
+                                 site=site)
+        content_type_id = ContentType.objects.get_for_model(item).pk
+        return super().get_queryset(object_id, content_type_id)
