@@ -131,10 +131,8 @@ class Page(TimeStampedModel, ActivableModel, AbstractDraftable,
             order_by('section', 'order').\
             values_list('order', 'block__pk', 'section',
                         'block__is_active', 'is_active')
-
         blocks_list = []
         excluded_blocks_list = []
-
         # for every page block, check if it's active and if
         # relative block is active and populate two lists
         # blocks_list = []
@@ -149,8 +147,7 @@ class Page(TimeStampedModel, ActivableModel, AbstractDraftable,
             if block_is_active and page_block_is_active:
                 blocks_list.append((block, count))
             elif not page_block_is_active:
-                excluded_blocks_list.append((block, count))
-
+                excluded_blocks_list.append(block)
         # get all active template blocks
         template_blocks = self.base_template.\
             pagetemplateblock_set.\
@@ -164,9 +161,12 @@ class Page(TimeStampedModel, ActivableModel, AbstractDraftable,
         template_blocks_list = []
         for (count, block) in enumerate(template_blocks):
             template_blocks_list.append((block, count))
-        # exclude blocks in exclude_blocks_list[]
-        template_blocks_list = [x for x in template_blocks_list
-                                if x not in excluded_blocks_list]
+
+        for exc_block in excluded_blocks_list:
+            for tpl_block in template_blocks_list:
+                if tpl_block[0] == exc_block:
+                    template_blocks_list.remove(tpl_block)
+                    break
 
         # populate a set excluding template blocks existing in page_blocks
         # (same active blocks in same section and same order position!)
